#' ---
#' title: 'Example report with iris data'
#' author: 'Gilles San Martin'
#' date: '`r Sys.setlocale("LC_ALL", "en_GB.UTF-8"); format(Sys.time(), "%d %B %Y")`'
#' output:  
#'      pdf_document:
#'          toc: true
#'          fig_caption: true
#'          highlight: tango
#' geometry: margin=0.7in
#' header-includes:
#'      - \usepackage{float}
#'      - \usepackage{fancyvrb}
#'      - \usepackage{graphicx} # needed for fig.align = 'center' option
#'      - \usepackage{pdflscape} # to have some pages in landscape orientation
#' ---

# /* 
# ---------------- This part is just for report production -------------------
# */

#+ echo = FALSE, warning = FALSE, error = FALSE, message = FALSE
# source("/home/gilles/stats/makereport.R")
# makereport("template_spin.R", output = c("latex", "odt", "html"), odtdpi = 300, wd= "/home/gilles/stats")

library(knitr)
opts_chunk$set(dev = c("png", "cairo_pdf"), fig.width = 10/2.54, fig.height= 10/2.54,
               fig.align='center', dpi = 300,
               echo=TRUE, results= "markup", warning = FALSE, 
               error = FALSE, message = FALSE, cache = TRUE, tidy = FALSE, 
               tidy.opts=list(width.cutoff=95))

library(pander)
panderOptions("table.style" , "rmarkdown")
panderOptions("table.split.table" , Inf)
panderOptions("table.alignment.rownames" , "right")

options(width = 110)

#'
#'  
#' *********************************************************************************
#'
#' \newpage
#' 

# /* 
# ---------------- Load packages and scripts -------------------
# */

#+ echo = FALSE
# source some usfull home made function and set the working directory (not run here)

# source("/home/gilles/stats/mytoolbox.R")
# source("/home/gilles/stats/model.select_0.4.R")
# 
# setwd("/home/gilles/stats")

# load ggplot, change the default theme and change the locale (language = English)
library(ggplot2)
#+ results = "hide", echo = FALSE
Sys.setlocale("LC_ALL", 'en_GB.UTF-8')
mytheme <- theme_bw(10) + theme(axis.text.x=element_text(size=8),
                                legend.key = element_rect(color = NA))
theme_set(mytheme)


library(lme4)
library(car)

# /* 
# ---------------- Import Data -------------------
# */

#' # Data used
#' 
#' Dataset for 3 _Iris_ species (_Iris virginica_, _Iris setosa_, _Iris versicolor_) with
#' 4 morphological variables measured : 
#' 
#' * Sepal length
#' * Sepal width
#' * Petal length
#' * Petal width
#' 

data(iris)
d <- iris

#' **Random sample :**
pander(d[sample(1:nrow(d), 5),])

#' **Summary :**
summary(d)
str(d)

#' 
#' You can use inline code (i.e. calculations inside the text for which only the output 
#' is displayed in the final document. For example :      
#' The mean sepal length for all species is `r mean(d$Sepal.Length)` cm.
#' 


#'
#' \pagebreak
#' 

# /* 
# ---------------- Graphs -------------------
# */

#' # Graphical representation of the data
#' 
#' ## Scatterplot matrix

# dev.new(width = 12/2.54, height = 8/2.54)
#+ fig.width = 12/2.54, fig.height = 8/2.54
pairs(d, gap = 0)

#' ## Boxplot
#' 
# dev.new(width = 7.5/2.54, height = 7/2.54)
#+ fig.width = 7.5/2.54, fig.height = 7/2.54
par(mar = c(3,3,2,1), mgp = c(1.8, 0.5, 0), las = 1, cex = 0.8)
plot(Sepal.Length ~ Species, data=d)


# /* 
# ---------------- Analyses -------------------
# */

#' # Anova 

m <- lm(Sepal.Length ~ Species, data = d)
Anova(m)

#'      
#' You can also print the results of the Anova as a table
#'    
#' 
pander(Anova(m))


# /* 
# ---------------- Maths -------------------
# */

#'   
#' # Maths
#' The arithmetic mean is : $\frac{1}{n} \sum_{i=i}^{n} x_{i}$
#' 
#' The arithmetic mean is : $$\frac{1}{n} \sum_{i=i}^{n} x_{i}$$

#'
#' \newpage
#' 

# /* 
# ---------------- Session Info & Citations -------------------
# */

#' # References

#'
#' **R packages :**  
#' 
#' We used lme4 (Bates et al) for mixed models, 
#' mulcomp (Hothorn et al) for Post-Hoc tests, 
#' ggplot2 (Wickham) for most graphics, 
#' car (Fox & Weisberg) for Type II tests in the two stage analysis only 
#' (not with the mixed models !) and of course R.

#+ echo = FALSE
opts_chunk$set(results= "asis", echo = FALSE)

#'  
print(citation("lme4"), style = "text")
#'  
print(citation("car"), style = "text")
#'  
print(citation("multcomp"), style = "text")
#'  
print(citation(), style = "text")
#'  
print(citation("ggplot2"), style = "text")
# 

# 
# # sapply(.packages(), function(x) print(citation(x), style = "textVersion")


#' 
#' **Other References :**  
#' 

#' Bretz, F., Hothorn, T., Westfall, P., Westfall, P.H., 2010. Multiple Comparisons Using R. CRC Press.
#' 
#' Burnham, K.P., Anderson, D.R., 2002. Model selection and multimodel inference. Springer. 
#'  
#' Fox, J., 2002. An R and S Plus Companion to Applied Regression, 1st ed. Sage Publications, Inc.  
#' 
#' Gelman, A., Hill, J., 2007. Data analysis using regression and multilevel/hierarchical models. Cambridge University Press.  
#' 
#' Pinheiro, J.C., Bates, D.M., 2000. Mixed-Effects Models in S and S-PLUS. Springer, New-York.
#' 
#' Venables, W.N., Ripley, B.D., 2003. Modern Applied Statistics with S, 4th ed. Springer.
#' 
#' Zuur, A.F., Ieno, E.N., Smith, G.M., 2007. Analysing ecological data. Springer.  
#' 
#' Zuur, A.F., Ieno, E.N., Walker, N., Saveliev, A.A., Smith, G.M., 2009. Mixed Effects Models and Extensions in Ecology With R. Springer-Verlag New York Inc.  
#' 
#' \pagebreak



opts_chunk$set(results= "markup")

#' # Session Info
sessionInfo()






